@@ -3,11 +3,11 @@ package State::Machine::Failure::Simple;
 
 use Bubblegum::Class;
 use Function::Parameters;
-use Bubblegum::Constraints 'typeof_arrayref';
+use Bubblegum::Constraints -typesof;
 
 extends 'State::Machine::Failure';
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 has config => (
     is       => 'ro',
